@@ -55,25 +55,34 @@ class DingDingPlugin(NotificationPlugin):
         print(url_arr)
         issue_id = url_arr[url_arr.index('issues') + 1]
         print(issue_id)
-
         issue_data = requests.get(
-            url="http://web-middle.ruibogyl.work/sentry/findIssueTargetUrl",
-            headers={"Content-Type": "application/json"},
-            data=json.dumps({
-                "id": issue_id
-            })).json()
-
-        print(issue_data)
-
+            "http://web-middle.ruibogyl.work/sentry/findIssueTargetUrl",
+            {'id': issue_id},
+            headers={"Content-Type": "application/json"}
+        ).json()
+        print issue_data['data']['url']
+        response = requests.get(
+            "http://web-middle.ruibogyl.work/sentry/getDingDingAssignee",
+            {'url': issue_data['data']['url']},
+            headers={"Content-Type": "application/json"}
+        ).json()
+        print response['data']['phone']
         data = {
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": u"#### test {title} \n > {message} [href]({url})".format(
+                "text": "#### {title} \n > {message} \n [点击查看问题]({event_url}) \n @{phone}".format(
                     title=title,
                     message=event.message,
-                    url=u"{}events/{}/".format(group.get_absolute_url(), event.id),
-                )
+                    event_url=event_url,
+                    phone=response['data']['phone'],
+                ),
+            },
+            "at": {
+                "atMobiles": [
+                    response['phone']
+                ],
+                "isAtAll": False
             }
         }
         requests.post(
